@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -108,7 +108,8 @@ class Plugin(GlancesPlugin):
                 network_new = netiocounters
                 for net in network_new:
                     # Do not take hidden interface into account
-                    if self.is_hide(net):
+                    # or KeyError: 'eth0' when interface is not connected #1348
+                    if self.is_hide(net) or net not in netstatus:
                         continue
                     try:
                         cumulative_rx = network_new[net].bytes_recv
