@@ -2,7 +2,7 @@
 #
 # This file is part of Glances.
 #
-# Copyright (C) 2018 Nicolargo <nicolas@nicolargo.com>
+# Copyright (C) 2019 Nicolargo <nicolas@nicolargo.com>
 #
 # Glances is free software; you can redistribute it and/or modify
 # it under the terms of the GNU Lesser General Public License as published by
@@ -279,7 +279,10 @@ class GlancesProcesses(object):
                 try:
                     top_process = psutil.Process(proc['pid'])
                     extended_stats = ['cpu_affinity', 'ionice',
-                                      'num_ctx_switches', 'num_fds']
+                                      'num_ctx_switches']
+                    if LINUX:
+                        # num_fds only avalable on Unix system (see issue #1351)
+                        extended_stats += ['num_fds']
                     if WINDOWS:
                         extended_stats += ['num_handles']
 
@@ -375,39 +378,70 @@ def weighted(value):
     return -float('inf') if value is None else value
 
 
-def sort_stats(stats, sortedby=None, reverse=True):
+def _sort_io_counters(process,
+                      sortedby='io_counters',
+                      sortedby_secondary='memory_percent'):
+    """Specific case for io_counters
+    Sum of io_r + io_w"""
+    return process[sortedby][0] - process[sortedby][2] + process[sortedby][1] - process[sortedby][3]
+
+
+def _sort_cpu_times(process,
+                    sortedby='cpu_times',
+                    sortedby_secondary='memory_percent'):
+    """ Specific case for cpu_times
+    Patch for "Sorting by process time works not as expected #1321"
+    By default PsUtil only takes user time into account
+    see (https://github.com/giampaolo/psutil/issues/1339)
+    The following implementation takes user and system time into account"""
+    return process[sortedby][0] + process[sortedby][1]
+
+
+def _sort_lambda(sortedby='cpu_percent',
+                 sortedby_secondary='memory_percent'):
+    """Return a sort lambda function for the sortedbykey"""
+    ret = None
+    if sortedby == 'io_counters':
+        ret = _sort_io_counters
+    elif sortedby == 'cpu_times':
+        ret = _sort_cpu_times
+    return ret
+
+
+def sort_stats(stats,
+               sortedby='cpu_percent',
+               sortedby_secondary='memory_percent',
+               reverse=True):
     """Return the stats (dict) sorted by (sortedby).
 
     Reverse the sort if reverse is True.
     """
-    sortedby_secondary = 'cpu_percent'
-    if sortedby is None:
+    if sortedby is None and sortedby_secondary is None:
         # No need to sort...
         return stats
-    elif sortedby is 'cpu_percent':
-        sortedby_secondary = 'memory_percent'
 
-    if sortedby == 'io_counters':
-        # Specific case for io_counters
-        # Sum of io_r + io_w
+    # Check if a specific sort should be done
+    sort_lambda = _sort_lambda(sortedby=sortedby,
+                               sortedby_secondary=sortedby_secondary)
+
+    if sort_lambda is not None:
+        # Specific sort
         try:
-            # Sort process by IO rate (sum IO read + IO write)
-            stats.sort(key=lambda process: process[sortedby][0] -
-                       process[sortedby][2] + process[sortedby][1] -
-                       process[sortedby][3],
-                       reverse=reverse)
+            stats.sort(key=sort_lambda, reverse=reverse)
         except Exception:
-            stats.sort(key=lambda x: (weighted(x['cpu_percent']),
-                                      weighted(x['memory_percent'])),
+            # If an error is detected, fallback to cpu_percent
+            stats.sort(key=lambda process: (weighted(process['cpu_percent']),
+                                            weighted(process[sortedby_secondary])),
                        reverse=reverse)
     else:
-        # Others sorts
+        # Standard sort
         try:
-            stats.sort(key=lambda x: (weighted(x[sortedby]),
-                                      weighted(x[sortedby_secondary])),
+            stats.sort(key=lambda process: (weighted(process[sortedby]),
+                                            weighted(process[sortedby_secondary])),
                        reverse=reverse)
         except (KeyError, TypeError):
-            stats.sort(key=operator.itemgetter('name'),
+            # Fallback to name
+            stats.sort(key=lambda process: process['name'] if process['name'] is not None else '~',
                        reverse=False)
 
     return stats
